use crate::config;
use crate::config::Config;
use actix_web::web::{self, Data};
use log::info;

pub async fn notify(msg: &str, title: &str, config: Data<Config>) {
    if let Some(gotify) = config.gotify_config() {
        gotify_notification(msg, title, gotify).await;
    }
    if let Some(webhook) = config.webhook_config() {
        info!("Sending webhook notification");
        let request =
            serde_json::json!({
                "instance": config.name(),
                "title": title,
                "msg": msg
            });

        let client = reqwest::blocking::Client::new();
        client
            .post(webhook)
            .json(&request)
            .send()
            .expect("Failed to send webhook request");
    }
}

async fn gotify_notification(msg: &str, title: &str, config: config::GotifySettings) {
    info!("Sending gotify notification");
    let c = reqwest::Client::new();
    let _ = c
        .post(format!("https://{}/message?token={}", config.host, config.token))
        .header("title", title)
        .header("message", msg)
        .header("priority", 5)
        .send()
        .await;
}
